@@ -58,7 +58,7 @@
   
   # Set upper limit to Inf
   if(is.na(range[2])) range[2] <- Inf
-  
+
   # Some internal checks that should never be triggered.
   if(length(x) != 1){
     ..error_reached_unreachable_code(".check_number_in_valid_range_x_not_length_1")
@@ -68,6 +68,11 @@
     ..error_reached_unreachable_code(".check_number_in_valid_range_inverted_range")
   }
   
+  # Check that x is numeric or NA.
+  if(!is.numeric(x) & !is.na(x)){
+    ..error_type_not_valid(x, var_name, "numeric")
+  }
+  
   if(!is.na(x)){
     is_outside_range <- ifelse(closed[1], x < range[1], x <= range[1]) | ifelse(closed[2], x > range[2], x >= range[2])
     
