@@ -494,6 +494,9 @@ setMethod("export_auc_data", signature(object="familiarCollection"),
                    export_collection=FALSE,
                    ...){
             
+            # Make sure the collection object is updated.
+            object <- update_object(object=object)
+            
             return(.export(x=object,
                            data_slot="auc_data",
                            dir_path=dir_path,
