@@ -183,6 +183,9 @@ setMethod("plot_auc_roc_curve", signature(object="familiarCollection"),
                    export_collection=FALSE,
                    ...){
             
+            # Make sure the collection object is updated.
+            object <- update_object(object=object)
+            
             return(do.call(.plot_auc_curve,
                            args=list("object"=object,
                                      "curve_type"="roc",
@@ -383,6 +386,9 @@ setMethod("plot_auc_precision_recall_curve", signature(object="familiarCollectio
                    export_collection=FALSE,
                    ...){
             
+            # Make sure the collection object is updated.
+            object <- update_object(object=object)
+            
             return(do.call(.plot_auc_curve,
                            args=list("object"=object,
                                      "curve_type"="pr",
