@@ -206,6 +206,9 @@ setMethod("plot_decision_curve", signature(object="familiarCollection"),
             # Suppress NOTES due to non-standard evaluation in data.table
             curve_type <- ci_low <- ci_up <- net_benefit <- NULL
             
+            # Make sure the collection object is updated.
+            object <- update_object(object=object)
+            
             # Get input data.
             x <- export_decision_curve_analysis_data(object=object, aggregate_results=TRUE)
             
@@ -299,13 +302,6 @@ setMethod("plot_decision_curve", signature(object="familiarCollection"),
                            tail(y_breaks, n=1))
             }
             
-            # # Adapt the confidence intervals so that they fit in the y-range.
-            # if(conf_int_style != "none"){
-            #   x@data[curve_type == "model" & is.finite(ci_low) & ci_low < y_range[1] & ci_up > y_range[1], "ci_low":=y_range[1]]
-            #   x@data[curve_type == "model" & is.finite(ci_up) & ci_up > y_range[2] & ci_low < y_range[2], "ci_up":=y_range[2]]
-            # }
-            
-
             if(object@outcome_type %in% c("binomial", "multinomial")){
               split_variable <- "positive_class"
               
