@@ -55,10 +55,10 @@ testthat::test_that("k-nearest neighbour model trained correctly", {
 testthat::test_that("k-nearest neighbour model has no variable importance", {
   
   # Extract the variable importance table.
-  vimp_table <- familiar:::..vimp(good_model)
+  vimp_table <- familiar:::get_vimp_table(good_model)
   
   # Expect that the vimp table is empty.
-  testthat::expect_equal(is_empty(vimp_table), TRUE)
+  testthat::expect_equal(familiar:::is_empty(vimp_table), TRUE)
 })
 
 
@@ -68,7 +68,7 @@ testthat::test_that("k-nearest neighbour model can train on wide data", {
   testthat::expect_equal(familiar:::model_is_trained(wide_model), TRUE)
   
   # Variable importance table is absent
-  testthat::expect_equal(is_empty(familiar:::..vimp(wide_model)), TRUE)
+  testthat::expect_equal(familiar:::is_empty(familiar:::get_vimp_table(wide_model)), TRUE)
   
   # Valid predictions.
   testthat::expect_equal(familiar:::any_predictions_valid(familiar:::.predict(wide_model, wide_data), outcome_type=wide_data@outcome_type), TRUE)
@@ -118,10 +118,10 @@ testthat::test_that("k-nearest neighbour model trained correctly", {
 testthat::test_that("k-nearest neighbour model has no variable importance", {
   
   # Extract the variable importance table.
-  vimp_table <- familiar:::..vimp(good_model)
+  vimp_table <- familiar:::get_vimp_table(good_model)
   
   # Expect that the vimp table is empty.
-  testthat::expect_equal(is_empty(vimp_table), TRUE)
+  testthat::expect_equal(familiar:::is_empty(vimp_table), TRUE)
 })
 
 
@@ -131,7 +131,7 @@ testthat::test_that("k-nearest neighbour model can train on wide data", {
   testthat::expect_equal(familiar:::model_is_trained(wide_model), TRUE)
   
   # Variable importance table is absent.
-  testthat::expect_equal(is_empty(familiar:::..vimp(wide_model)), TRUE)
+  testthat::expect_equal(familiar:::is_empty(familiar:::get_vimp_table(wide_model)), TRUE)
   
   # Valid predictions.
   testthat::expect_equal(familiar:::any_predictions_valid(familiar:::.predict(wide_model, wide_data), outcome_type=wide_data@outcome_type), TRUE)
@@ -183,7 +183,7 @@ testthat::test_that("k-nearest neighbour model trained correctly", {
 testthat::test_that("k-nearest neighbour model does not have variable importance", {
   
   # Extract the variable importance table.
-  vimp_table <- familiar:::..vimp(good_model)
+  vimp_table <- familiar:::get_vimp_table(good_model)
   
   # Expect that the vimp table has no rows.
   testthat::expect_equal(familiar:::is_empty(vimp_table), TRUE)
@@ -196,7 +196,7 @@ testthat::test_that("k-nearest neighbour model can train on wide data", {
   testthat::expect_equal(familiar:::model_is_trained(wide_model), TRUE)
   
   # Variable importance table is absent.
-  testthat::expect_equal(familiar:::is_empty(familiar:::..vimp(wide_model)), TRUE)
+  testthat::expect_equal(familiar:::is_empty(familiar:::get_vimp_table(wide_model)), TRUE)
   
   # Valid predictions.
   testthat::expect_equal(familiar:::any_predictions_valid(familiar:::.predict(wide_model, wide_data), outcome_type=wide_data@outcome_type), TRUE)
@@ -247,7 +247,7 @@ testthat::test_that("k-nearest neighbour model trained correctly", {
 testthat::test_that("k-nearest neighbour model has no variable importance", {
   
   # Extract the variable importance table.
-  vimp_table <- familiar:::..vimp(good_model)
+  vimp_table <- familiar:::get_vimp_table(good_model)
   
   # Expect that the vimp table is empty.
   testthat::expect_equal(familiar:::is_empty(vimp_table), TRUE)
@@ -260,7 +260,7 @@ testthat::test_that("k-nearest neighbour model can train on wide data", {
   testthat::expect_equal(familiar:::model_is_trained(wide_model), TRUE)
   
   # Variable importance table is empty.
-  testthat::expect_equal(familiar:::is_empty(familiar:::..vimp(wide_model)), TRUE)
+  testthat::expect_equal(familiar:::is_empty(familiar:::get_vimp_table(wide_model)), TRUE)
   
   # Valid predictions cannot be made.
   testthat::expect_equal(familiar:::any_predictions_valid(familiar:::.predict(wide_model, wide_data), outcome_type=wide_data@outcome_type), TRUE)
